qec\_lego\_bench.codes package
==============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   qec_lego_bench.codes.noisy_codes
   qec_lego_bench.codes.stabilizer_codes

Submodules
----------

qec\_lego\_bench.codes.circuit\_code module
-------------------------------------------

.. automodule:: qec_lego_bench.codes.circuit_code
   :members:
   :undoc-members:
   :show-inheritance:

qec\_lego\_bench.codes.code module
----------------------------------

.. automodule:: qec_lego_bench.codes.code
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: qec_lego_bench.codes
   :members:
   :undoc-members:
   :show-inheritance:
